==> haskell-unliftio-core-0.1.2.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio-core
version: 0.1.2.0
id: unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
key: unliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio-core#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>
category: Control
abi: f455d126eaad42d9d326e7b0a54e0e51
exposed: True
exposed-modules:
    Control.Monad.IO.Unlift
hidden-modules: Paths_unliftio_core
import-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-core-0.1.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-core-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/unliftio-core-0.1.2.0
hs-libraries: HSunliftio-core-0.1.2.0-900TPot3SR34dceIcVaslS
depends:
    base-4.11.1.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock
haddock-html: /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-core-0.1.2.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio-core
version: 0.1.2.0
id: unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
key: unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio-core#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio-core>
category: Control
abi: 371c9b2ef161ad979213a97f93b9a344
exposed: True
exposed-modules:
    Control.Monad.IO.Unlift
hidden-modules: Paths_unliftio_core
import-dirs: /usr/lib/ghc-8.6.1/site-local/unliftio-core-0.1.2.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/unliftio-core-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/unliftio-core-0.1.2.0
hs-libraries: HSunliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
depends:
    base-4.12.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-unliftio-core/html/unliftio-core.haddock
haddock-html: /usr/share/doc/haskell-unliftio-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
